/*
 * SimpleApp Demo
 * 
 * Copyright (c) 2010, CodeRight
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice and this list of conditions.
 *   - Redistributions in binary form must reproduce the above
 *     copyright notice and this list of conditions in the 
 *     documentation and/or other materials provided with the 
 *     distribution.
 * 
 * Jazz Desktop Application Framework
 * http://jazz.coderight.nl
 * 
 * Author: Will Boluyt
 */
package nl.coderight.jazz.demo.about;

import java.awt.Color;
import java.awt.FlowLayout;

import nl.coderight.jazz.demo.event.MenuEvent;
import nl.coderight.jazz.demo.event.MenuEvent.MenuEventType;

import nl.coderight.jazz.form.FormView;
import nl.coderight.jazz.form.control.GroupControl;
import nl.coderight.jazz.form.field.ImageField;
import nl.coderight.jazz.form.field.LabelField;
import nl.coderight.jazz.form.field.LabelField.Align;
import nl.coderight.jazz.form.field.button.PushButton;
import nl.coderight.jazz.util.JazzConfig;

public class AboutView extends FormView {
	private ImageField logoField;
	private LabelField versionLabel;
	private PushButton closeButton;
	
	
	public void handleEvent(MenuEvent evt) {
		switch (evt.getType()) {
		case CLOSE:
			close();
			break;
			
		default:
			propagateEvent(evt);
			break;
		}
	}

	@Override
	protected void init() {
		createFields();
		createLayout();
	}

	private void createFields() {
		logoField = new ImageField();
		logoField.setValue(getResourceAsImage("jazz-logo.jpg"));
		
		versionLabel = new LabelField("Version: " + JazzConfig.getInstance().getVersion(), Align.CENTER);
		versionLabel.setBackground(Color.LIGHT_GRAY);
		versionLabel.setOpaque(true);
		
		closeButton = new PushButton("button.close");
		closeButton.setOnClickEvent(new MenuEvent(MenuEventType.CLOSE));
	}

	private void createLayout() {
		addField(createFieldGroup(), CENTER);
		addField(createButtonGroup(), SOUTH);
	}

	private GroupControl createFieldGroup() {
		GroupControl fieldGroup = new GroupControl();
		
		fieldGroup.addField(logoField, CENTER);
		fieldGroup.addField(versionLabel, SOUTH);
		
		return fieldGroup;
	}

	private GroupControl createButtonGroup() {
		GroupControl buttonGroup = new GroupControl();
		buttonGroup.setLayout(new FlowLayout());
		
		buttonGroup.addField(closeButton);
		
		return buttonGroup;
	}
	
}
