/*
 * SimpleApp Demo
 * 
 * Copyright (c) 2010, CodeRight
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice and this list of conditions.
 *   - Redistributions in binary form must reproduce the above
 *     copyright notice and this list of conditions in the 
 *     documentation and/or other materials provided with the 
 *     distribution.
 * 
 * Jazz Desktop Application Framework
 * http://jazz.coderight.nl
 * 
 * Author: Will Boluyt
 */
package nl.coderight.jazz.demo.contact;

import java.awt.FlowLayout;
import java.util.List;

import nl.coderight.jazz.action.Action;
import nl.coderight.jazz.demo.action.CancelAction;
import nl.coderight.jazz.demo.action.SubmitAction;
import nl.coderight.jazz.demo.event.ContactEvent;
import nl.coderight.jazz.demo.field.AddressField;
import nl.coderight.jazz.demo.field.ContactField;

import nl.coderight.jazz.dialog.MessageType;
import nl.coderight.jazz.dialog.OptionDialog;
import nl.coderight.jazz.dialog.OptionType;
import nl.coderight.jazz.dialog.ReturnOptionType;
import nl.coderight.jazz.form.FormHeader;
import nl.coderight.jazz.form.FormView;
import nl.coderight.jazz.form.control.GroupControl;
import nl.coderight.jazz.form.field.button.PushButton;
import nl.coderight.jazz.form.validation.ValidationError;
import nl.coderight.jazz.form.validation.ValidationEvent;
import nl.coderight.jazz.help.HelpID;

@HelpID("start")
public class ContactView extends FormView {
	private FormHeader formHeader;
	private PushButton submitButton;
	private PushButton cancelButton;
	private Action submitAction;
	private Action cancelAction;


	public void handleEvent(ContactEvent evt) {
		switch (evt.getType()) {
		case CANCEL:
			close();
			break;
			
		case SUBMIT:
			// check for validation errors
			List<ValidationError> errors = validate();
			if (!errors.isEmpty()) {
				// there are validation errors so do not submit...
				errors.get(0).getField().focus();
				break;
			} else {
				// submit form and close view
				submit();
				close();
				// fall-through!
			}
			
		default:
			// propagate event to controller
			propagateEvent(evt);
			break;
		}
	}
	
	@Override
	public void handleEvent(ValidationEvent evt) {
		switch (evt.getType()) {
		case VALID:
			// no error, clear message
			formHeader.setDescription("");
			break;
			
		case ERROR:
			// error, set message
			formHeader.setDescription(evt.getError().getMessage());
			formHeader.setDescriptionIcon(getResourceAsIcon("error.icon"));
			break;
		}
	}

	@Override
	public void close() {
		// check if form is changed, if true show dialog
		if (isChanged()) {
			OptionDialog dialog = new OptionDialog(this);
			dialog.setMessageType(MessageType.QUESTION);
			dialog.setTitle("dialog.discard.title");
			dialog.setMessage("dialog.discard.message");
			dialog.setOptionType(OptionType.YES_NO);
			dialog.setOptions("button.yes", "button.no", "");
			dialog.show();
			if (dialog.getReturnOptionType() == ReturnOptionType.NO) {
				focus();
				return;
			}
		}
		super.close();
	}
	
	@Override
	protected void init() {
		createActions();
		createFields();
		createLayout();
	}
	
	private void createActions() {
		submitAction = new SubmitAction();
		cancelAction = new CancelAction();
		// enable submit button when form is changed
		setOnChangeAction(submitAction);
	}

	private void createFields() {
		submitButton = new PushButton(submitAction);
		cancelButton = new PushButton(cancelAction);
	}

	private void createLayout() {
		setHeader(createHeader());
		addField(createForm());
	}

	private FormHeader createHeader() {
		formHeader = new FormHeader();
		formHeader.setTitle("header.form");
		formHeader.setRightImage(getResourceAsImage("vcard.jpg"));
		return formHeader;
	}
	
	private GroupControl createForm() {
		GroupControl form = new GroupControl();
		form.addField(new ContactField("contact"), NORTH);
		form.addField(new AddressField("contact.address"), CENTER);
		form.addField(createButtons(), SOUTH);		
		return form;
	}
	
	private GroupControl createButtons() {
		GroupControl buttons = new GroupControl();
		buttons.setLayout(new FlowLayout(FlowLayout.RIGHT));
		buttons.addField(submitButton);
		buttons.addField(cancelButton);
		return buttons;
	}
	
}
